@@ -1,3 +1,9 @@
+-- SchemaCrawler
+-- http://www.schemacrawler.com
+-- Copyright (c) 2000-2025, Sualeh Fatehi <sualeh@hotmail.com>.
+-- All rights reserved.
+-- SPDX-License-Identifier: EPL-2.0
+
 SELECT
   NULL AS TABLE_CAT,
   PRIMARY_KEYS.OWNER AS TABLE_SCHEM,
@@ -23,6 +29,7 @@ FROM
       AND USERS.ORACLE_MAINTAINED = 'N'
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^APEX_[0-9]{6}$')
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^FLOWS_[0-9]{5}$')
+      AND NOT REGEXP_LIKE(USERS.USERNAME, '^OPS\$ORACLE$')
 WHERE
   REGEXP_LIKE(PRIMARY_KEYS.OWNER, '${schema-inclusion-rule}')
   AND REGEXP_LIKE(PRIMARY_KEYS.OWNER || '.' || PRIMARY_KEYS.TABLE_NAME, '${table-inclusion-rule}')
