@@ -1,3 +1,9 @@
+-- SchemaCrawler
+-- http://www.schemacrawler.com
+-- Copyright (c) 2000-2025, Sualeh Fatehi <sualeh@hotmail.com>.
+-- All rights reserved.
+-- SPDX-License-Identifier: EPL-2.0
+
 SELECT
   NULL AS CONSTRAINT_CATALOG,
   CONSTRAINTS.OWNER AS CONSTRAINT_SCHEMA,
@@ -18,6 +24,7 @@ FROM
       AND USERS.ORACLE_MAINTAINED = 'N'
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^APEX_[0-9]{6}$')
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^FLOWS_[0-9]{5}$')
+      AND NOT REGEXP_LIKE(USERS.USERNAME, '^OPS\$ORACLE$')
 WHERE
   REGEXP_LIKE(CONSTRAINTS.OWNER, '${schema-inclusion-rule}')
   AND REGEXP_LIKE(CONSTRAINTS.OWNER || '.' || CONSTRAINTS.TABLE_NAME, '${table-inclusion-rule}')
