@@ -1,3 +1,9 @@
+-- SchemaCrawler
+-- http://www.schemacrawler.com
+-- Copyright (c) 2000-2025, Sualeh Fatehi <sualeh@hotmail.com>.
+-- All rights reserved.
+-- SPDX-License-Identifier: EPL-2.0
+
 SELECT
   NULL AS VIEW_CATALOG,
   VIEW_TABLE_USAGE.OWNER AS VIEW_SCHEMA,
@@ -12,6 +18,7 @@ FROM
       AND USERS.ORACLE_MAINTAINED = 'N'
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^APEX_[0-9]{6}$')
       AND NOT REGEXP_LIKE(USERS.USERNAME, '^FLOWS_[0-9]{5}$')
+      AND NOT REGEXP_LIKE(USERS.USERNAME, '^OPS\$ORACLE$')
 WHERE
   VIEW_TABLE_USAGE.TYPE = 'VIEW'
   AND REGEXP_LIKE(VIEW_TABLE_USAGE.OWNER, '${schema-inclusion-rule}')
